@@ -92,7 +92,16 @@ class CapitalGainsCalculator:
             portfolio[symbol] = quantity
         # Add to acquisition_list to apply same day rule
         if transaction.action in [ActionType.STOCK_ACTIVITY, ActionType.SPIN_OFF]:
-            amount = quantity * self.initial_prices.get(transaction.date, symbol)
+            stock_price_gbp = None
+
+            if transaction.price is not None and transaction.currency is not None:
+                stock_price_gbp = self.converter.to_gbp(
+                    transaction.price, transaction.currency, transaction.date
+                )
+            else:
+                stock_price_gbp = self.initial_prices.get(transaction.date, symbol)
+
+            amount = quantity * stock_price_gbp
         else:
             if transaction.amount is None:
                 raise AmountMissingError(transaction)
@@ -459,7 +468,7 @@ class CapitalGainsCalculator:
                         disposal_price,
                         acquisition_price,
                     )
-                    disposal_quantity -= acquisition_quantity
+                    disposal_quantity -= available_quantity
                     proceeds_amount -= available_quantity * disposal_price
                     current_price = current_amount / current_quantity
                     amount_delta = available_quantity * current_price
@@ -492,9 +501,7 @@ class CapitalGainsCalculator:
                         )
                     )
         if disposal_quantity > 0:
-            allowable_cost = (
-                current_amount * Decimal(disposal_quantity) / Decimal(current_quantity)
-            )
+            allowable_cost = current_amount * disposal_quantity / current_quantity
             chargeable_gain += proceeds_amount - allowable_cost
             LOGGER.debug(
                 "SECTION 104, quantity %d, gain %s, proceeds amount %s, "
@@ -657,17 +664,17 @@ def main() -> int:
     calculator = CapitalGainsCalculator(args.year, converter, initial_prices)
     # First pass converts broker transactions to HMRC transactions.
     # This means applying same day rule and collapsing all transactions with
-    # same type in the same day.
+    # same type within the same day.
     # It also converts prices to GBP, validates data and calculates dividends,
     # taxes on dividends and interest.
     acquisition_list, disposal_list = calculator.convert_to_hmrc_transactions(
         broker_transactions
     )
-    # Second pass calculates capital gain tax for the given tax year
+    # Second pass calculates capital gain tax for the given tax year.
     report = calculator.calculate_capital_gain(acquisition_list, disposal_list)
     print(report)
 
-    # Generate PDF report
+    # Generate PDF report.
     if not args.no_report:
         render_latex.render_calculations(
             report,
@@ -682,3 +689,7 @@ def main() -> int:
 def init() -> None:
     """Entry point."""
     sys.exit(main())
+
+
+if __name__ == "__main__":
+    init()
